Index: src/arm/simulator-arm.h |
diff --git a/src/arm/simulator-arm.h b/src/arm/simulator-arm.h |
index 907a5906658d19c99c37c5795c5004ece9923a1d..b918ecf9638a4825163f0f1874f54877a5371bd0 100644 |
--- a/src/arm/simulator-arm.h |
+++ b/src/arm/simulator-arm.h |
@@ -414,14 +414,14 @@ class Simulator { |
static const uint32_t kStopDisabledBit = 1 << 31; |
// A stop is enabled, meaning the simulator will stop when meeting the |
// instruction, if bit 31 of watched_stops[code].count is unset. |
// The value watched_stops[code].count & ~(1 << 31) indicates how many times |
// the breakpoint was hit or gone through. |
struct StopCountAndDesc { |
uint32_t count; |
char* desc; |
}; |
- StopCountAndDesc watched_stops[kNumOfWatchedStops]; |
+ StopCountAndDesc watched_stops_[kNumOfWatchedStops]; |
}; |
@@ -414,14 +414,14 @@ class Simulator { |
static const uint32_t kStopDisabledBit = 1 << 31; |
// A stop is enabled, meaning the simulator will stop when meeting the |
- // instruction, if bit 31 of watched_stops[code].count is unset. |
- // The value watched_stops[code].count & ~(1 << 31) indicates how many times |
+ // instruction, if bit 31 of watched_stops_[code].count is unset. |
+ // The value watched_stops_[code].count & ~(1 << 31) indicates how many times |
// the breakpoint was hit or gone through. |
struct StopCountAndDesc { |